Struct sp_runtime::CryptoTypeId
pub struct CryptoTypeId(pub [u8; 4]);Expand description
Re-export this since it’s part of the API of this crate. An identifier for a specific cryptographic algorithm used by a key pair
Tuple Fields
0: [u8; 4]Trait Implementations
impl Clone for CryptoTypeId
impl Clone for CryptoTypeId
fn clone(&self) -> CryptoTypeId
fn clone(&self) -> CryptoTypeId
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for CryptoTypeId
impl Debug for CryptoTypeId
impl Decode for CryptoTypeId
impl Decode for CryptoTypeId
fn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy
) -> Result<CryptoTypeId, Error>where
__CodecInputEdqy: Input,
fn decode<__CodecInputEdqy>( __codec_input_edqy: &mut __CodecInputEdqy ) -> Result<CryptoTypeId, Error>where __CodecInputEdqy: Input,
Attempt to deserialise the value from input.
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>( input: &mut I, dst: &mut MaybeUninit<Self> ) -> Result<DecodeFinished, Error>where I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
fn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
fn skip<I>(input: &mut I) -> Result<(), Error>where I: Input,
Attempt to skip the encoded value from input. Read more
fn encoded_fixed_size() -> Option<usize>
fn encoded_fixed_size() -> Option<usize>
Returns the fixed encoded size of the type. Read more
impl Default for CryptoTypeId
impl Default for CryptoTypeId
fn default() -> CryptoTypeId
fn default() -> CryptoTypeId
Returns the “default value” for a type. Read more
impl<'de> Deserialize<'de> for CryptoTypeId
impl<'de> Deserialize<'de> for CryptoTypeId
fn deserialize<__D>(
__deserializer: __D
) -> Result<CryptoTypeId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>( __deserializer: __D ) -> Result<CryptoTypeId, <__D as Deserializer<'de>>::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Encode for CryptoTypeId
impl Encode for CryptoTypeId
fn encode_to<__CodecOutputEdqy>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy
)where
__CodecOutputEdqy: Output + ?Sized,
fn encode_to<__CodecOutputEdqy>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy )where __CodecOutputEdqy: Output + ?Sized,
Convert self to a slice and append it to the destination.
fn using_encoded<R, F>(&self, f: F) -> Rwhere
F: FnOnce(&[u8]) -> R,
fn using_encoded<R, F>(&self, f: F) -> Rwhere F: FnOnce(&[u8]) -> R,
Convert self to a slice and then invoke the given closure with it.
fn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl Hash for CryptoTypeId
impl Hash for CryptoTypeId
impl Ord for CryptoTypeId
impl Ord for CryptoTypeId
impl PartialEq<CryptoTypeId> for CryptoTypeId
impl PartialEq<CryptoTypeId> for CryptoTypeId
fn eq(&self, other: &CryptoTypeId) -> bool
fn eq(&self, other: &CryptoTypeId) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl PartialOrd<CryptoTypeId> for CryptoTypeId
impl PartialOrd<CryptoTypeId> for CryptoTypeId
fn partial_cmp(&self, other: &CryptoTypeId) -> Option<Ordering>
fn partial_cmp(&self, other: &CryptoTypeId) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Serialize for CryptoTypeId
impl Serialize for CryptoTypeId
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>( &self, __serializer: __S ) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where __S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for CryptoTypeId
impl EncodeLike<CryptoTypeId> for CryptoTypeId
impl Eq for CryptoTypeId
impl StructuralEq for CryptoTypeId
impl StructuralPartialEq for CryptoTypeId